<?php
defined( 'ABSPATH' ) or die();

/**
 * Load custom scripts
 */
function lana_custom_scripts() {

	/** custom wordpress widgets */
	wp_register_script( 'lana-custom-widgets', get_template_directory_uri() . '/js/custom-widgets.js', array( 'jquery' ), LANA_BLOG_VERSION, true );
	wp_enqueue_script( 'lana-custom-widgets' );

	/** custom wordpress theme */
	wp_register_script( 'lana-custom-theme', get_template_directory_uri() . '/js/custom-theme.js', array( 'jquery' ), LANA_BLOG_VERSION, true );
	wp_enqueue_script( 'lana-custom-theme' );
}

add_action( 'wp_enqueue_scripts', 'lana_custom_scripts' );

/**
 * Lana Gallery
 * columns script edit
 */
function lana_media_gallery_columns_scripts() {

	wp_register_script( 'lana-media-gallery', get_template_directory_uri() . '/js/media-gallery.js', array( 'jquery' ), '1.0.0' );
	wp_enqueue_script( 'lana-media-gallery' );
}

function lana_media_gallery_columns() {
	add_action( 'admin_print_scripts', 'lana_media_gallery_columns_scripts' );
}

add_action( 'wp_enqueue_media', 'lana_media_gallery_columns' );

/**
 * Post - add class
 *
 * @param $classes
 *
 * @return array
 */
function lana_post_class( $classes ) {

	if ( comments_open() ) {
		$classes[] = 'comment-open';
	}

	if ( ! comments_open() ) {
		$classes[] = 'comment-closed';
	}

	return $classes;
}

add_filter( 'post_class', 'lana_post_class' );

/**
 * Lana Pagination
 */
function lana_pagination() {

	global $wp_query;

	$posts_per_page = intval( get_query_var( 'posts_per_page' ) );
	$paged          = intval( get_query_var( 'paged' ) );
	$numposts       = $wp_query->found_posts;
	$max_page       = $wp_query->max_num_pages;
	if ( $numposts <= $posts_per_page ) {
		return;
	}
	if ( empty( $paged ) || $paged == 0 ) {
		$paged = 1;
	}
	$pages_to_show   = 7;
	$half_page_start = floor( ( $pages_to_show - 1 ) / 2 );
	$half_page_end   = ceil( ( $pages_to_show - 1 ) / 2 );
	$start_page      = $paged - $half_page_start;
	if ( $start_page <= 0 ) {
		$start_page = 1;
	}
	$end_page = $paged + $half_page_end;
	if ( ( $end_page - $start_page ) != ( $pages_to_show - 1 ) ) {
		$end_page = $start_page + ( $pages_to_show - 1 );
	}
	if ( $end_page > $max_page ) {
		$start_page = $max_page - ( $pages_to_show - 1 );
		$end_page   = $max_page;
	}
	if ( $start_page <= 0 ) {
		$start_page = 1;
	}

	/**
	 * Pagination html
	 * tags
	 */
	$pagination_before              = '<ul class="pagination">';
	$pagination_after               = '</ul>';
	$pagination_element_before      = '<li class="%s">';
	$pagination_element_after       = '</li>';
	$pagination_element_link_before = '<a class="%s" href="%s">';
	$pagination_element_link_after  = '</a>';

	/**
	 * Generate
	 * output
	 */
	echo $pagination_before;

	/**
	 * Previous
	 * button
	 */
	$previous_posts_link = get_previous_posts_link( '&laquo; Previous' );
	$previous_attr_class = '';

	if ( ! $previous_posts_link ) {
		$previous_posts_link .= sprintf( $pagination_element_link_before, '', '#' );
		$previous_posts_link .= __( '&laquo; Previous', 'lana-blog' );
		$previous_posts_link .= $pagination_element_link_after;

		$previous_attr_class = 'disabled';
	}

	echo sprintf( $pagination_element_before, $previous_attr_class );
	echo $previous_posts_link;
	echo $pagination_element_after;

	/**
	 * Page number
	 * list
	 */
	for ( $i = $start_page; $i <= $end_page; $i ++ ) {

		$page_attr_class = '';
		$page_attr_href  = get_pagenum_link( $i );

		if ( $i == $paged ) {
			$page_attr_class = 'active';
			$page_attr_href  = '#';
		}

		echo sprintf( $pagination_element_before, $page_attr_class );
		echo sprintf( $pagination_element_link_before, '', $page_attr_href );
		echo $i;
		echo $pagination_element_link_after;
	}

	/**
	 * Next
	 * button
	 */
	$next_posts_link = get_next_posts_link( 'Next &raquo;' );
	$next_attr_class = '';

	if ( ! $next_posts_link ) {
		$next_posts_link .= sprintf( $pagination_element_link_before, '', '#' );
		$next_posts_link .= __( 'Next &raquo;', 'lana-blog' );
		$next_posts_link .= $pagination_element_link_after;

		$next_attr_class = 'disabled';
	}

	echo sprintf( $pagination_element_before, $next_attr_class );
	echo $next_posts_link;
	echo $pagination_element_after;

	echo $pagination_after;
}

/**
 * Lana wp_list_comments
 * callback function
 *
 * @param $comment
 * @param $args
 * @param $depth
 */
function lana_comment( $comment, $args, $depth ) {

	$GLOBALS['comment'] = $comment;
	?>
    <li <?php comment_class( 'media' ); ?> id="comment-<?php comment_ID(); ?>">
        <div class="pull-left">
			<?php echo get_avatar( $comment, $size = '48' ); ?>
        </div>
        <div class="media-body">
            <h4 class="media-heading">
				<?php printf( __( '%s says:', 'lana-blog' ), get_comment_author_link() ); ?>
            </h4>

            <div class="comment-text">
				<?php comment_text(); ?>
            </div>
            <h6>
                <span class="pull-left comment-meta comment-metadata">
                    <a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>">
	                    <?php printf( __( '%1$s at %2$s', 'lana-blog' ), get_comment_date(), get_comment_time() ); ?>
                    </a>
                </span>
                <span class="pull-right reply">
                    <?php
                    comment_reply_link( array_merge( $args, array(
	                    'depth'     => $depth,
	                    'max_depth' => $args['max_depth']
                    ) ) );
                    ?>
                </span>
                <span class="pull-right edit">
                    <?php edit_comment_link( __( 'Edit', 'lana-blog' ) ); ?>
                </span>
                <span class="clearfix"></span>
            </h6>
        </div>
    </li>
    <hr/>
	<?php
}

/**
 * Comment form fields
 *
 * @param $fields
 *
 * @return array
 */
function lana_comment_form_fields( $fields ) {

	$commenter = wp_get_current_commenter();

	$req      = get_option( 'require_name_email' );
	$aria_req = $req ? " aria-required='true'" : '';

	$fields['author'] = '<div class="form-group">
	                        <label class="col-sm-offset-1 col-sm-2 control-label" for="author">' . __( 'Name', 'lana-blog' ) . '</label>
	                        <div class="col-sm-6">
	                            <input type="text" class="form-control" id="author" name="author" value="' . esc_attr( $commenter['comment_author'] ) . '" placeholder="' . __( 'Name', 'lana-blog' ) . '" ' . $aria_req . '>
	                        </div>
	                        <div class="col-sm-1 no-padding">
	                            <p class="form-control-static">' . ( $req ? __( '* required', 'lana-blog' ) : '' ) . '</p>
	                        </div>
	                    </div>';

	$fields['email'] = '<div class="form-group">
	                        <label class="col-sm-offset-1 col-sm-2 control-label" for="email">' . __( 'Email', 'lana-blog' ) . '</label>
	                        <div class="col-sm-6">
	                            <input type="text" class="form-control" id="email" name="email" value="' . esc_attr( $commenter['comment_author_email'] ) . '" placeholder="' . __( 'Email address', 'lana-blog' ) . '" ' . $aria_req . '>
	                        </div>
	                        <div class="col-sm-1 no-padding">
	                            <p class="form-control-static">' . ( $req ? __( '* required', 'lana-blog' ) : '' ) . '</p>
	                        </div>
	                    </div>';

	$fields['url'] = '<div class="form-group">
	                        <label class="col-sm-offset-1 col-sm-2 control-label" for="url">' . __( 'Website', 'lana-blog' ) . '</label>
	                        <div class="col-sm-6">
	                            <input type="text" class="form-control" id="url" name="url" value="' . esc_attr( $commenter['comment_author_url'] ) . '" placeholder="' . esc_attr( get_option( 'siteurl' ) ) . '">
	                        </div>
	                    </div>';

	return $fields;
}

add_filter( 'comment_form_default_fields', 'lana_comment_form_fields' );

/**
 * Change comment form fields sort
 * comment to last
 *
 * @param $fields
 *
 * @return mixed
 */
function lana_comment_form_fields_sort( $fields ) {

	$comment = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment;

	return $fields;
}

add_filter( 'comment_form_fields', 'lana_comment_form_fields_sort' );

/**
 * Comment form
 *
 * @param $args
 *
 * @return mixed
 */
function lana_comment_form( $args ) {

	$args['comment_field'] = '<div class="form-group">
	                            <label class="sr-only" for="comment">' . __( 'Comment', 'lana-blog' ) . '</label>
	                                <div class="col-sm-offset-1 col-sm-10">
	                                    <textarea class="form-control" name="comment" id="comment" rows="8" maxlength="65525" aria-required="true" required="required"></textarea>
	                                </div>
	                            </div>';

	if ( '' != $args['comment_notes_before'] ) {
		$args['comment_notes_before'] = '<div class="form-group">
			                                <div class="col-sm-offset-1 col-sm-10 text-center">
												' . $args['comment_notes_before'] . '
											</div>
		                                </div>';
	}

	if ( '' != $args['comment_notes_after'] ) {
		$args['comment_notes_after'] = '<div class="form-group">
			                                <div class="col-sm-offset-1 col-sm-10">
			                                ' . $args['comment_notes_before'] . '
			                                </div>
		                                </div>';
	}

	$args['class_form']   = 'comment-form form-horizontal';
	$args['class_submit'] = 'btn btn-primary';

	$args['title_reply_before'] = '<h4 id="reply-title" class="comment-reply-title text-center">';
	$args['title_reply_after']  = '</h4>';

	$args['submit_field'] = '<div class="form-group">
								<div class="col-sm-offset-1 col-sm-10 text-center">
								%1$s %2$s
									<p class="form-control-static">
										' . cancel_comment_reply_link() . '
									</p>
								</div>
							</div>';

	$args['must_log_in']  = '<div class="text-center">
                                ' . $args['must_log_in'] . '
                            </div>';
	$args['logged_in_as'] = '<div class="form-group">
                                <div class="col-sm-12">
                                    <div class="form-control-static text-center">
                                    ' . $args['logged_in_as'] . '
                                    </div>
                                </div>
                            </div>';

	return $args;
}

add_filter( 'comment_form_defaults', 'lana_comment_form' );

/**
 * Lana Password Protected Form
 * with Bootstrap
 * @return string
 */
function lana_password_form() {
	global $post;

	$label = 'pwbox-' . rand();

	if ( is_a( $post, 'WP_Post' ) ) {
		$label = 'pwbox-' . $post->ID;
	}

	/** @var string $output */
	$output = '';

	$output .= '<div class="row">';
	$output .= '<div class="col-md-6">';
	$output .= '<form class="post-password-form" action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post">';
	$output .= '<div class="input-group">';
	$output .= '<label class="sr-only" for="' . $label . '">';
	$output .= __( 'Password:', 'lana-blog' );
	$output .= '</label>';
	$output .= '<input type="password" name="post_password" id="' . $label . '" class="form-control" size="20">';
	$output .= '<span class="input-group-btn"><input type="submit" name="Submit" class="btn btn-primary" value="' . esc_attr__( 'Submit', 'lana-blog' ) . '"/></span>';
	$output .= '</div>';
	$output .= '</form>';
	$output .= '</div>';
	$output .= '<div class="col-md-12">';
	$output .= '<p>' . __( 'This content is password protected. To view it please enter your password.', 'lana-blog' ) . '</p>';
	$output .= '</div>';
	$output .= '</div>';

	return $output;
}

add_filter( 'the_password_form', 'lana_password_form' );

/**
 * Lana Image
 * add magnific class and rensponsive image class
 *
 * @param $html
 *
 * @return mixed
 */
function lana_add_image_class( $html ) {

	/** empty content */
	if ( empty( $html ) ) {
		return $html;
	}

	$html     = mb_convert_encoding( $html, 'HTML-ENTITIES', 'UTF-8' );
	$document = new DOMDocument();
	libxml_use_internal_errors( true );
	$document->loadHTML( utf8_decode( $html ) );

	/**
	 * Set links
	 * <a> tag
	 */
	$a_tags = $document->getElementsByTagName( 'a' );

	/** @var DOMElement $a */
	foreach ( $a_tags as $a ) {

		$has_img = false;

		foreach ( $a->childNodes as $children ) {
			if ( $children->nodeName == 'img' ) {
				$has_img = true;
			}
		}

		if ( ! $has_img ) {
			continue;
		}

		$a_existing_class = $a->getAttribute( 'class' );
		$a_existing_class = explode( ' ', $a_existing_class );

		/** add class if not exists */
		if ( ! in_array( 'magnific', $a_existing_class ) ) {
			$a_existing_class[] = 'magnific';
		}

		$a->setAttribute( 'class', implode( ' ', $a_existing_class ) );
	}

	/**
	 * Set images
	 * <img> tag
	 */
	$img_tags = $document->getElementsByTagName( 'img' );

	/** @var DOMElement $img */
	foreach ( $img_tags as $img ) {
		$img_existing_class = $img->getAttribute( 'class' );
		$img_existing_class = explode( ' ', $img_existing_class );

		/** add class if not exists */
		if ( ! in_array( 'img-responsive', $img_existing_class ) ) {
			$img_existing_class[] = 'img-responsive';
		}

		$img->setAttribute( 'class', implode( ' ', $img_existing_class ) );
	}

	$html = $document->saveHTML();

	return $html;
}

add_filter( 'the_content', 'lana_add_image_class', 10, 1 );

/**
 * Lana Custom
 * Tag Cloud Widget
 *
 * @param $args
 *
 * @return mixed
 */
function lana_widget_tag_cloud_args( $args ) {

	$args['number']   = 20;
	$args['largest']  = 18;
	$args['smallest'] = 13;
	$args['unit']     = 'px';

	return $args;
}

add_filter( 'widget_tag_cloud_args', 'lana_widget_tag_cloud_args' );

/**
 * Modify Read More Link
 * @return string
 */
function lana_more_link() {
	return '<a href="' . get_permalink() . '">' . __( 'Read More', 'lana-blog' ) . ' &raquo;</a>';
}

add_filter( 'the_content_more_link', 'lana_more_link' );

/**
 * Remove Thumbnail dimensions
 * remove height and width (responsive)
 *
 * @param $html
 *
 * @return mixed
 */
function lana_thumbnail_dimensions( $html ) {
	$html = preg_replace( '/(width|height)=\"\d*\"\s/', '', $html );

	return $html;
}

add_filter( 'post_thumbnail_html', 'lana_thumbnail_dimensions', 10 );
add_filter( 'image_send_to_editor', 'lana_thumbnail_dimensions', 10 );

/**
 * Gallery sortcode
 * with Bootstrap
 *
 * @param $output
 * @param $attr
 * @param $instance
 *
 * @return string
 */
function lana_gallery_shortcode( $output, $attr, $instance ) {

	$post = get_post();

	/**
	 * Order by
	 * settings
	 */
	if ( isset( $attr['orderby'] ) ) {
		$attr['orderby'] = sanitize_sql_orderby( $attr['orderby'] );
		if ( ! $attr['orderby'] ) {
			unset( $attr['orderby'] );
		}
	}

	/**
	 * Shortcode attrs
	 * settings
	 */
	$a = shortcode_atts( array(
		'order'      => 'ASC',
		'orderby'    => 'menu_order ID',
		'id'         => $post->ID,
		'itemtag'    => 'div',
		'icontag'    => 'a',
		'captiontag' => 'div',
		'columns'    => 3,
		'size'       => 'thumbnail',
		'include'    => '',
		'exclude'    => '',
		'link'       => ''
	), $attr );

	$id = intval( $a['id'] );

	/**
	 * Attachments include
	 * settings
	 */
	if ( ! empty ( $a['include'] ) ) {

		$a['include'] = preg_replace( '/[^0-9,]+/', '', $a['include'] );

		/** @var $_attachments */
		$_attachments = get_posts( array(
			'include'        => $a['include'],
			'post_status'    => 'inherit',
			'post_type'      => 'attachment',
			'post_mime_type' => 'image',
			'order'          => $a['order'],
			'orderby'        => $a['orderby']
		) );

		$attachments = array();
		foreach ( $_attachments as $key => $val ) {
			$attachments[ $val->ID ] = $_attachments[ $key ];
		}

	} elseif ( ! empty( $a['exclude'] ) ) {

		$a['exclude'] = preg_replace( '/[^0-9,]+/', '', $a['exclude'] );

		/** @var $_attachments */
		$attachments = get_children( array(
			'post_parent'    => $id,
			'exclude'        => $a['exclude'],
			'post_status'    => 'inherit',
			'post_type'      => 'attachment',
			'post_mime_type' => 'image',
			'order'          => $a['order'],
			'orderby'        => $a['orderby']
		) );
	} else {

		/** @var $_attachments */
		$attachments = get_children( array(
			'post_parent'    => $id,
			'post_status'    => 'inherit',
			'post_type'      => 'attachment',
			'post_mime_type' => 'image',
			'order'          => $a['order'],
			'orderby'        => $a['orderby']
		) );
	}

	if ( empty( $attachments ) ) {
		return '';
	}

	/**
	 * gallery for feed
	 */
	if ( is_feed() ) {
		$output = "\n";
		foreach ( $attachments as $attachment_id => $attachment ) {
			$output .= wp_get_attachment_link( $attachment_id, $a['size'], true ) . "\n";
		}

		return $output;
	}

	/**
	 * tag
	 * tag_escape
	 */
	$itemtag    = tag_escape( $a['itemtag'] );
	$captiontag = tag_escape( $a['captiontag'] );

	$col         = 12 / $a['columns'];
	$col_counter = 0;

	/**
	 * Generate
	 * output
	 */
	$output .= '<' . $itemtag . ' id="gallery-' . $instance . '" class="gallery">';

	/**
	 * @var int $id
	 * @var WP_Post $attachment
	 */
	foreach ( $attachments as $attachment ) {

		if ( $col_counter == 0 ) {
			$output .= '<' . $itemtag . ' class="row">';
		}

		$attachment_image = wp_get_attachment_image( $attachment->ID, false, true, false );
		$attachment_link  = wp_get_attachment_link( $attachment->ID, 'full', false, false, $attachment_image );

		$output .= '<' . $itemtag . ' class="col-md-' . $col . '">';
		$output .= '<' . $itemtag . ' class="' . $a['size'] . '">';
		$output .= $attachment_link;

		if ( $captiontag && trim( $attachment->post_excerpt ) ) {
			$output .= ' <' . $captiontag . ' class="caption">';
			$output .= '<p>' . wptexturize( $attachment->post_excerpt ) . '</p>';
			$output .= '</' . $captiontag . '>';
		}

		$output .= '</' . $itemtag . '>';
		$output .= '</' . $itemtag . '>';

		$col_counter += $col;

		if ( $col_counter >= 12 ) {
			$output .= '</' . $itemtag . '>';
			$col_counter = 0;
		}
	}

	if ( $col_counter != 0 ) {
		$output .= '</' . $itemtag . '>';
	}

	$output .= '</' . $itemtag . '>';

	return $output;
}

add_filter( 'post_gallery', 'lana_gallery_shortcode', 10, 3 );

/**
 * Image Caption
 * with Bootstrap
 *
 * @param $output
 * @param $attr
 * @param $content
 *
 * @return string
 */
function lana_img_caption_shortcode( $output, $attr, $content ) {

	$atts = shortcode_atts( array(
		'id'      => '',
		'align'   => 'alignnone',
		'width'   => '',
		'caption' => ''
	), $attr );

	if ( $atts['width'] < 1 || empty( $atts['caption'] ) ) {
		return $content;
	}

	if ( $atts['align'] == 'alignleft' ) {
		$atts['align'] .= ' pull-left';
	}

	if ( $atts['align'] == 'alignright' ) {
		$atts['align'] .= ' pull-right';
	}

	$img_caption_before              = '<div id="%s" class="%s">';
	$img_caption_after               = '</div>';
	$img_caption_caption_before      = '<div class="%s">';
	$img_caption_caption_after       = '</div>';
	$img_caption_caption_text_before = '<p>';
	$img_caption_caption_text_after  = '</p>';

	/**
	 * Generate
	 * output
	 */
	$output .= sprintf( $img_caption_before, $atts['id'], implode( ' ', array(
		'img-caption',
		'thumbnail',
		$atts['align']
	) ) );
	$output .= do_shortcode( $content );
	$output .= sprintf( $img_caption_caption_before, 'caption' );
	$output .= $img_caption_caption_text_before;
	$output .= $atts['caption'];
	$output .= $img_caption_caption_text_after;
	$output .= $img_caption_caption_after;
	$output .= $img_caption_after;

	return $output;
}

add_filter( 'img_caption_shortcode', 'lana_img_caption_shortcode', 10, 3 );

/**
 * Lana
 * main navbar in header class
 *
 * @param string $class
 */
function lana_main_navbar_in_header_class( $class = '' ) {
	echo 'class="' . join( ' ', lana_get_main_navbar_in_header_class( $class ) ) . '"';
}

/**
 * Lana
 * get main navbar in header class
 *
 * @param string $class
 *
 * @return array
 */
function lana_get_main_navbar_in_header_class( $class = '' ) {

	$classes = array();

	if ( $class ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}
		$classes = array_map( 'esc_attr', $class );
	} else {
		// Ensure that we always coerce class to being an array.
		$class = array();
	}

	$classes = array_map( 'esc_attr', $classes );

	$classes = apply_filters( 'lana_main_navbar_in_header_class', $classes, $class );

	return array_unique( $classes );
}

/**
 * Lana
 * main navbar in header container class
 *
 * @param string $class
 */
function lana_main_navbar_in_header_container_class( $class = '' ) {
	echo 'class="' . join( ' ', lana_get_main_navbar_in_header_container_class( $class ) ) . '"';
}

/**
 * Lana
 * get main navbar in header container class
 *
 * @param string $class
 *
 * @return array
 */
function lana_get_main_navbar_in_header_container_class( $class = '' ) {

	$classes = array();

	if ( $class ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}
		$classes = array_map( 'esc_attr', $class );
	} else {
		// Ensure that we always coerce class to being an array.
		$class = array();
	}

	$classes = array_map( 'esc_attr', $classes );

	$classes = apply_filters( 'lana_main_navbar_in_header_container_class', $classes, $class );

	return array_unique( $classes );
}

/**
 * Lana
 * main navbar in content class
 *
 * @param string $class
 */
function lana_main_navbar_in_content_class( $class = '' ) {
	echo 'class="' . join( ' ', lana_get_main_navbar_in_content_class( $class ) ) . '"';
}

/**
 * Lana
 * get main navbar in content class
 *
 * @param string $class
 *
 * @return array
 */
function lana_get_main_navbar_in_content_class( $class = '' ) {

	$classes = array();

	if ( $class ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}
		$classes = array_map( 'esc_attr', $class );
	} else {
		// Ensure that we always coerce class to being an array.
		$class = array();
	}

	$classes = array_map( 'esc_attr', $classes );

	$classes = apply_filters( 'lana_main_navbar_in_content_class', $classes, $class );

	return array_unique( $classes );
}

/**
 * Lana
 * main navbar in content container class
 *
 * @param string $class
 */
function lana_main_navbar_in_content_container_class( $class = '' ) {
	echo 'class="' . join( ' ', lana_get_main_navbar_in_content_container_class( $class ) ) . '"';
}

/**
 * Lana
 * get main navbar in content container class
 *
 * @param string $class
 *
 * @return array
 */
function lana_get_main_navbar_in_content_container_class( $class = '' ) {

	$classes = array();

	if ( $class ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}
		$classes = array_map( 'esc_attr', $class );
	} else {
		// Ensure that we always coerce class to being an array.
		$class = array();
	}

	$classes = array_map( 'esc_attr', $classes );

	$classes = apply_filters( 'lana_main_navbar_in_content_container_class', $classes, $class );

	return array_unique( $classes );
}

/**
 * Lana
 * main container class
 *
 * @param string $class
 */
function lana_main_container_class( $class = '' ) {
	echo 'class="' . join( ' ', lana_get_main_container_class( $class ) ) . '"';
}

/**
 * Lana
 * get main container class
 *
 * @param string $class
 *
 * @return array
 */
function lana_get_main_container_class( $class = '' ) {

	$classes = array();

	if ( $class ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}
		$classes = array_map( 'esc_attr', $class );
	} else {
		// Ensure that we always coerce class to being an array.
		$class = array();
	}

	$classes = array_map( 'esc_attr', $classes );

	$classes = apply_filters( 'lana_main_container_class', $classes, $class );

	return array_unique( $classes );
}

/**
 * Lana
 * header container class
 *
 * @param string $class
 */
function lana_header_container_class( $class = '' ) {
	echo 'class="' . join( ' ', lana_get_header_container_class( $class ) ) . '"';
}

/**
 * Lana
 * get header container class
 *
 * @param string $class
 *
 * @return array
 */
function lana_get_header_container_class( $class = '' ) {

	$classes = array();

	if ( $class ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}
		$classes = array_map( 'esc_attr', $class );
	} else {
		// Ensure that we always coerce class to being an array.
		$class = array();
	}

	$classes = array_map( 'esc_attr', $classes );

	$classes = apply_filters( 'lana_header_container_class', $classes, $class );

	return array_unique( $classes );
}

/**
 * Lana
 * header site title container class
 *
 * @param string $class
 */
function lana_header_site_title_container_class( $class = '' ) {
	echo 'class="' . join( ' ', lana_get_header_site_title_container_class( $class ) ) . '"';
}

/**
 * Lana
 * get header site title container class
 *
 * @param string $class
 *
 * @return array
 */
function lana_get_header_site_title_container_class( $class = '' ) {

	$classes = array();

	if ( $class ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}
		$classes = array_map( 'esc_attr', $class );
	} else {
		// Ensure that we always coerce class to being an array.
		$class = array();
	}

	$classes = array_map( 'esc_attr', $classes );

	$classes = apply_filters( 'lana_header_site_title_container_class', $classes, $class );

	return array_unique( $classes );
}

/**
 * Lana
 * breadcrumb container class
 *
 * @param string $class
 */
function lana_breadcrumb_container_class( $class = '' ) {
	echo 'class="' . join( ' ', lana_get_breadcrumb_container_class( $class ) ) . '"';
}

/**
 * Lana
 * get breadcrumb container class
 *
 * @param string $class
 *
 * @return array
 */
function lana_get_breadcrumb_container_class( $class = '' ) {

	$classes = array();

	if ( $class ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}
		$classes = array_map( 'esc_attr', $class );
	} else {
		// Ensure that we always coerce class to being an array.
		$class = array();
	}

	$classes = array_map( 'esc_attr', $classes );

	$classes = apply_filters( 'lana_breadcrumb_container_class', $classes, $class );

	return array_unique( $classes );
}

/**
 * Lana
 * breadcrumb container inner class
 *
 * @param string $class
 */
function lana_breadcrumb_container_inner_class( $class = '' ) {
	echo 'class="' . join( ' ', lana_get_breadcrumb_container_inner_class( $class ) ) . '"';
}

/**
 * Lana
 * get breadcrumb container inner class
 *
 * @param string $class
 *
 * @return array
 */
function lana_get_breadcrumb_container_inner_class( $class = '' ) {

	$classes = array();

	if ( $class ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}
		$classes = array_map( 'esc_attr', $class );
	} else {
		// Ensure that we always coerce class to being an array.
		$class = array();
	}

	$classes = array_map( 'esc_attr', $classes );

	$classes = apply_filters( 'lana_breadcrumb_container_inner_class', $classes, $class );

	return array_unique( $classes );
}

/**
 * Lana
 * content container class
 *
 * @param string $class
 */
function lana_content_container_class( $class = '' ) {
	echo 'class="' . join( ' ', lana_get_content_container_class( $class ) ) . '"';
}

/**
 * Lana
 * get content container class
 *
 * @param string $class
 *
 * @return array
 */
function lana_get_content_container_class( $class = '' ) {

	$classes = array();

	if ( $class ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}
		$classes = array_map( 'esc_attr', $class );
	} else {
		// Ensure that we always coerce class to being an array.
		$class = array();
	}

	$classes = array_map( 'esc_attr', $classes );

	$classes = apply_filters( 'lana_content_container_class', $classes, $class );

	return array_unique( $classes );
}

/**
 * Lana
 * content class
 *
 * @param string $class
 */
function lana_content_class( $class = '' ) {
	echo 'class="' . join( ' ', lana_get_content_class( $class ) ) . '"';
}

/**
 * Lana
 * get content class
 *
 * @param string $class
 *
 * @return array
 */
function lana_get_content_class( $class = '' ) {

	$classes = array();

	if ( $class ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}
		$classes = array_map( 'esc_attr', $class );
	} else {
		// Ensure that we always coerce class to being an array.
		$class = array();
	}

	$classes = array_map( 'esc_attr', $classes );

	$classes = apply_filters( 'lana_content_class', $classes, $class );

	return array_unique( $classes );
}

/**
 * Lana
 * sidebar class
 *
 * @param string $class
 */
function lana_sidebar_class( $class = '' ) {
	echo 'class="' . join( ' ', lana_get_sidebar_class( $class ) ) . '"';
}

/**
 * Lana
 * get sidebar class
 *
 * @param string $class
 *
 * @return array
 */
function lana_get_sidebar_class( $class = '' ) {

	$classes = array();

	if ( $class ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}
		$classes = array_map( 'esc_attr', $class );
	} else {
		// Ensure that we always coerce class to being an array.
		$class = array();
	}

	$classes = array_map( 'esc_attr', $classes );

	$classes = apply_filters( 'lana_sidebar_class', $classes, $class );

	return array_unique( $classes );
}

/**
 * Lana
 * pre footer class
 *
 * @param string $class
 */
function lana_pre_footer_class( $class = '' ) {
	echo 'class="' . join( ' ', lana_get_pre_footer_class( $class ) ) . '"';
}

/**
 * Lana
 * get pre footer class
 *
 * @param string $class
 *
 * @return array
 */
function lana_get_pre_footer_class( $class = '' ) {

	$classes = array();

	if ( $class ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}
		$classes = array_map( 'esc_attr', $class );
	} else {
		// Ensure that we always coerce class to being an array.
		$class = array();
	}

	$classes = array_map( 'esc_attr', $classes );

	$classes = apply_filters( 'lana_pre_footer_class', $classes, $class );

	return array_unique( $classes );
}

/**
 * Content - col class
 *
 * @param $classes
 *
 * @return array|string
 */
function lana_content_col_class( $classes ) {

	/** with sidebar */
	if ( is_active_sidebar( 'primary' ) ) {
		$classes[] = 'col-md-9';
	}

	/** without sidebar - full width */
	if ( ! is_active_sidebar( 'primary' ) ) {
		$classes[] = 'col-md-12';
	}

	return $classes;
}

add_filter( 'lana_content_class', 'lana_content_col_class' );

/**
 * Sidebar - col class
 *
 * @param $classes
 *
 * @return array
 */
function lana_sidebar_col_class( $classes ) {

	/** with sidebar */
	if ( is_active_sidebar( 'primary' ) ) {
		$classes[] = 'col-md-3';
	}

	return $classes;
}

add_filter( 'lana_sidebar_class', 'lana_sidebar_col_class' );